@@ -999,14 +999,6 @@ void MainWindow::setupHelpActions()
     actionHelpAboutTQt->setWhatsThis( whatsThisFrom( "Help|About TQt" ) );
     connect( actionHelpAboutTQt, TQT_SIGNAL( activated() ), TQT_TQOBJECT(this), TQT_SLOT( helpAboutTQt() ) );
 
-#if 0 //defined(TQT_NON_COMMERCIAL)
-    // ### not used anymore -- should be deleted?
-    actionHelpRegister = new DesignerAction( i18n("Register TQt"), TQPixmap(), i18n("&Register TQt..."), 0, TQT_TQOBJECT(this), 0 );
-    actionHelpRegister->setStatusTip( i18n("Opens a web browser at the evaluation form on www.trolltech.com") );
-    actionHelpRegister->setWhatsThis( i18n("Register with Trolltech") );
-    connect( actionHelpRegister, TQT_SIGNAL( activated() ), TQT_TQOBJECT(this), TQT_SLOT( helpRegister() ) );
-#endif
-
     actionHelpWhatsThis = new DesignerAction( i18n("What's This?"), TQIconSet( whatsthis_image, whatsthis_image ),
 				       i18n("What's This?"), SHIFT + Key_F1, TQT_TQOBJECT(this), 0 );
     actionHelpWhatsThis->setStatusTip( i18n("\"What's This?\" context sensitive help") );
@@ -1027,11 +1019,6 @@ void MainWindow::setupHelpActions()
     menu->insertSeparator();
     actionHelpAbout->addTo( menu );
     actionHelpAboutTQt->addTo( menu );
-#if 0 //defined(TQT_NON_COMMERCIAL)
-    // ### not used anymore -- should be deleted?
-    actionHelpRegister->addTo( menu );
-#endif
-
     menu->insertSeparator();
     actionHelpWhatsThis->addTo( menu );
 }
