@@ -32,7 +32,7 @@
 #include <tqpushbutton.h>
 #include <tqradiobutton.h>
 #include <tqwmatrix.h>
-
+#include <tqtooltip.h>
 
 // KDE
 #include <tdeaboutapplication.h>
@@ -206,6 +206,7 @@ KMixApplet::KMixApplet( const TQString& configFile, Type t,
 	// We do NOT know which mixer to use => ask the User
 	m_errorLabel = new TQPushButton( i18n("Select Mixer"), this );
 	m_errorLabel->setGeometry(0, 0, m_errorLabel->sizeHint().width(),  m_errorLabel->sizeHint().height() );
+	TQToolTip::add(m_errorLabel, "Select one of the available mixers");
 	resize( m_errorLabel->sizeHint() );
 	connect( m_errorLabel, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectMixer()) );
     }
@@ -287,6 +288,7 @@ void KMixApplet::loadConfig( TDEConfig *config, const TQString &grp )
     if ( m_mixerWidget ) {
 	//config->setGroup( grp );
 	KMixToolBox::loadConfig(m_mixerWidget->_mdws, config, grp, "PanelApplet" );
+	connect(m_mixerWidget, TQT_SIGNAL(selectMixer()), this, TQT_SLOT(selectMixer()));
     }
 }
 
@@ -322,7 +324,7 @@ void KMixApplet::selectMixer()
    bool ok = FALSE;
    TQString res = KInputDialog::getItem( i18n("Mixers"),
                                         i18n("Available mixers:"),
-					lst, 1, FALSE, &ok, this );
+					lst, 0, FALSE, &ok, this );
    if ( ok )
    {
       Mixer *mixer = Mixer::mixers().at( lst.findIndex( res ) );
