@@ -476,14 +476,6 @@ void MainWindow::setupRunActions()
   connect(this, TQT_SIGNAL(hasActiveForm(bool)), a, TQT_SLOT(setEnabled(bool)));
   a->plug(fileTb);
   a->plug(menu);
-  // add KDE4 executor
-
-  TDEAction* b = new TDEAction(i18n("Run Dialog K4"), "launch", CTRL + SHIFT  + TQt::Key_R,
-                           TQT_TQOBJECT(this), TQT_SLOT(runForm4()), actionCollection(), "run4");
-  b->setToolTip(i18n("Executes dialog in KDE4"));
-  b->setWhatsThis(whatsThisFrom("Run|Run dialog"));
-  connect(this, TQT_SIGNAL(hasActiveForm(bool)), b, TQT_SLOT(setEnabled(bool)));
-  b->plug(menu);
 }
 
 void MainWindow::setupWindowActions()
