@@ -309,7 +309,7 @@ BoxComponent::~BoxComponent()
 
 int BoxComponent::widthForHeight( int height )
 {
-	if ( d->direction !=Qt::Horizontal )
+	if ( d->direction != Horizontal )
 	{
 		int width = 0;
 		for ( uint n = 0; n < components(); ++n )
@@ -327,7 +327,7 @@ int BoxComponent::widthForHeight( int height )
 
 int BoxComponent::heightForWidth( int width )
 {
-	if ( d->direction ==Qt::Horizontal )
+	if ( d->direction == Horizontal )
 	{
 		int height = 0;
 		for ( uint n = 0; n < components(); ++n )
@@ -349,7 +349,7 @@ void BoxComponent::calcMinSize()
 	for ( uint n = 0; n < components(); ++n )
 	{
 		Component *comp = component( n );
-		if ( d->direction ==Qt::Horizontal )
+		if ( d->direction == Horizontal )
 		{
 			max = TQMAX( max, comp->minHeight() );
 			sum += comp->minWidth();
@@ -362,7 +362,7 @@ void BoxComponent::calcMinSize()
 	}
 
 	bool sizeChanged = false;
-	if ( d->direction ==Qt::Horizontal )
+	if ( d->direction == Horizontal )
 	{
 		if ( setMinWidth( sum ) ) sizeChanged = true;
 		if ( setMinHeight( max ) ) sizeChanged = true;
@@ -383,7 +383,7 @@ void BoxComponent::layout( const TQRect &rect )
 {
 	Component::layout( rect );
 
-	bool horiz = (d->direction ==Qt::Horizontal);
+	bool horiz = (d->direction == Horizontal);
 	int fixedSize = 0;
 	for ( uint n = 0; n < components(); ++n )
 	{
