@@ -2,7 +2,7 @@
  *   Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>                  *
  *   Copyright (C) 2004-2006 by Albert Astals Cid <tsdgeos@terra.es>       *
  *                                                                         *
- *   With portions of code from kpdf/kpdf_pagewidget.cc by:                *
+ *   With portions of code from kpdf/kpdf_pagewidget.cpp by:                *
  *     Copyright (C) 2002 by Wilco Greven <greven@kde.org>                 *
  *     Copyright (C) 2003 by Christophe Devriese                           *
  *                           <Christophe.Devriese@student.kuleuven.ac.be>  *
@@ -114,6 +114,7 @@ public:
     TDEToggleAction * aZoomFitText;
     TDEToggleAction * aViewTwoPages;
     TDEToggleAction * aViewContinuous;
+    TDEToggleAction * aViewCoverPage;
     TDEAction * aPrevAction;
 };
 
@@ -282,6 +283,11 @@ void PageView::setupActions( TDEActionCollection * ac )
     connect( d->aViewContinuous, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( slotContinuousToggled( bool ) ) );
     d->aViewContinuous->setChecked( KpdfSettings::viewContinuous() );
 
+    d->aViewCoverPage = new TDEToggleAction( i18n("Co&ver Page"), "contents2", 0, ac, "view_coverpage" );
+    connect( d->aViewCoverPage, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( slotCoverPageToggled( bool ) ) );
+    d->aViewCoverPage->setChecked( KpdfSettings::viewCoverPage() );
+    d->aViewCoverPage->setEnabled( KpdfSettings::viewColumns() > 1 );
+
     // Mouse-Mode actions
     d->aMouseNormal = new TDERadioAction( i18n("&Browse Tool"), "input-mouse", 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetMouseNormal() ), ac, "mouse_drag" );
     d->aMouseNormal->setExclusiveGroup( "MouseType" );
@@ -1652,6 +1658,7 @@ void PageView::doTypeAheadSearch()
 void PageView::slotRelayoutPages()
 // called by: notifySetup, viewportResizeEvent, slotTwoPagesToggled, slotContinuousToggled, updateZoom
 {
+    bool coverPageMode = ( KpdfSettings::viewColumns() == 2 && KpdfSettings::viewCoverPage() );
     // set an empty container if we have no pages
     int pageCount = d->items.count();
     if ( pageCount < 1 )
@@ -1682,11 +1689,12 @@ void PageView::slotRelayoutPages()
     {
         // Here we find out column's width and row's height to compute a table
         // so we can place widgets 'centered in virtual cells'.
-        int nCols = KpdfSettings::viewColumns(),
-            nRows = (int)ceil( (float)pageCount / (float)nCols ),
+        int pageShift = coverPageMode ? 1 : 0,
+            nCols = KpdfSettings::viewColumns(),
+            nRows = (int)ceil( (float)(pageCount + pageShift) / (float)nCols ),
             * colWidth = new int[ nCols ],
             * rowHeight = new int[ nRows ],
-            cIdx = 0,
+            cIdx = pageShift,
             rIdx = 0;
         for ( int i = 0; i < nCols; i++ )
             colWidth[ i ] = viewportWidth / nCols;
@@ -1716,13 +1724,18 @@ void PageView::slotRelayoutPages()
         // 2) arrange widgets inside cells
         int insertX = 0,
             insertY = 4; // 2 + 4*d->zoomFactor ?
-        cIdx = 0;
+        cIdx = pageShift;
         rIdx = 0;
+
         for ( iIt = d->items.begin(); iIt != iEnd; ++iIt )
         {
             PageViewItem * item = *iIt;
             int cWidth = colWidth[ cIdx ],
                 rHeight = rowHeight[ rIdx ];
+
+            if( coverPageMode && item->pageNumber() == 0 ) // align widget right inside viewport
+                insertX+=cWidth;
+
             // center widget inside 'cells'
             item->moveTo( insertX + (cWidth - item->width()) / 2,
                           insertY + (rHeight - item->height()) / 2 );
@@ -1776,14 +1789,24 @@ void PageView::slotRelayoutPages()
         // 2) hide all widgets except the displayable ones and dispose those
         int insertX = 0;
         cIdx = 0;
+
+        if( coverPageMode && (int)d->document->currentPage() == 0 )
+            ++cIdx;
+
         for ( iIt = d->items.begin(); iIt != iEnd; ++iIt )
         {
             PageViewItem * item = *iIt;
             if ( item == currentItem || (cIdx > 0 && cIdx < nCols) )
             {
-                // center widget inside 'cells'
-                item->moveTo( insertX + (colWidth[ cIdx ] - item->width()) / 2,
-                              (fullHeight - item->height()) / 2 );
+                if( KpdfSettings::viewCoverPage() && (int)d->document->currentPage() == 0 ) {
+                    // center widget inside viewport
+                    item->moveTo( insertX + (viewportWidth - item->width()) / 2,
+                                  (viewportHeight - item->height()) / 2 );
+                } else {
+                    // center widget inside 'cells'
+                    item->moveTo( insertX + (colWidth[ cIdx ] - item->width()) / 2,
+                                  (fullHeight - item->height()) / 2 );
+                }
                 // advance col index
                 insertX += colWidth[ cIdx ];
                 cIdx++;
@@ -2110,6 +2133,8 @@ void PageView::slotTwoPagesToggled( bool on )
         if ( d->document->pages() > 0 )
             slotRelayoutPages();
     }
+
+    d->aViewCoverPage->setEnabled( on );
 }
 
 void PageView::slotContinuousToggled( bool on )
@@ -2123,6 +2148,17 @@ void PageView::slotContinuousToggled( bool on )
     }
 }
 
+void PageView::slotCoverPageToggled( bool on )
+{
+    if ( KpdfSettings::viewCoverPage() != on )
+    {
+        KpdfSettings::setViewCoverPage( on );
+        KpdfSettings::writeConfig();
+        if ( d->document->pages() > 0 )
+            slotRelayoutPages();
+    }
+}
+
 void PageView::slotSetMouseNormal()
 {
     d->mouseMode = MouseNormal;
