@@ -496,7 +496,7 @@ void KWordQuizApp::slotFileOpen()
   TQCheckBox * cb = new TQCheckBox(i18n("&Join selected files into one list"), 0, 0);
   cb -> setChecked(false);
 
-  TQString filter = i18n("*.kvtml *.wql *.xml.gz *.csv|All Supported Documents\n*.kvtml|KDE Vocabulary Document\n*.wql|KWordQuiz Document\n*.xml.gz|Pauker Lesson\n*.csv|Comma-Separated Values");
+  TQString filter = i18n("*.kvtml *.wql *.xml.gz *.csv|All Supported Documents\n*.kvtml|TDE Vocabulary Document\n*.wql|KWordQuiz Document\n*.xml.gz|Pauker Lesson\n*.csv|Comma-Separated Values");
   KFileDialog *fd = new KFileDialog(TQString(), filter, this, 0, true, cb);
   fd -> setOperationMode(KFileDialog::Opening);
   fd -> setMode(KFile::Files | KFile::ExistingOnly);
@@ -584,7 +584,7 @@ bool KWordQuizApp::saveAsFileName( )
 
   bool success = false;
 
-  TQString filter = i18n("*.kvtml|KDE Vocabulary Document\n*.wql|KWordQuiz Document\n*.csv|Comma-Separated Values\n*.html|Hypertext Markup Language");
+  TQString filter = i18n("*.kvtml|TDE Vocabulary Document\n*.wql|KWordQuiz Document\n*.csv|Comma-Separated Values\n*.html|Hypertext Markup Language");
   KFileDialog *fd = new KFileDialog(TQString(), filter, this, 0, true);
   fd -> setOperationMode(KFileDialog::Saving);
   fd -> setCaption(i18n("Save Vocabulary Document As"));
