@@ -241,7 +241,7 @@ void Uic::createFormImpl( const TQDomElement &e )
 
     // children
     if( !objectNames.isEmpty() )
-    	tqWarning("WARNING : objectNames should be empty at "__FILE__" line %d\n", __LINE__);
+      tqWarning("WARNING : objectNames should be empty at %s line %d", __FILE__, __LINE__);
     nl = e.parentNode().toElement().elementsByTagName( "widget" );
     for ( i = 1; i < (int) nl.length(); i++ )
     { // start at 1, 0 is the toplevel widget
