@@ -59,6 +59,7 @@
 #include <klibloader.h>
 #include <tdeapplication.h>
 #include <tdelocale.h>
+#include <dcopglobal.h>
 
 #ifdef HAVE_SYS_PRCTL_H
 #include <sys/prctl.h>
@@ -852,12 +853,7 @@ static void init_tdeinit_socket()
           exit(255);
        }
      }
-     path = getenv("ICEAUTHORITY");
-     if (path.isEmpty())
-     {
-        path = home_dir;
-        path += "/.ICEauthority";
-     }
+     path = IceAuthFileName();
      if (access(path.data(), R_OK|W_OK) && (errno != ENOENT))
      {
        fprintf(stderr, "[tdeinit] Aborting. No write access to '%s'.\n", path.data());
